@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# (C) British Crown Copyright 2006-15 Met Office.
+# (C) British Crown Copyright 2006-16 Met Office.
 #
 # This file is part of FCM, tools for managing and building source code.
 #
@@ -140,6 +140,11 @@ sub add_trac_environment {
         my @command = (q{trac-admin}, $project->get_trac_live_path(), @args);
         $RUN->($log, sub {!system(@command)});
     };
+    my $TRAC_ADMIN_CONT = sub {
+        my ($log, @args) = @_;
+        my @command = (q{trac-admin}, $project->get_trac_live_path(), @args);
+        $RUNNER->run_continue($log, sub {!system(@command)});
+    };
     $TRAC_ADMIN->(
         "initialising Trac environment",
         q{initenv},
@@ -152,18 +157,22 @@ sub add_trac_environment {
     if ($group) {
         _chgrp_and_chmod($project->get_trac_live_path(), $group);
     }
+    # Note: For some reason, the commands to remove example components,
+    # versions, milestones, priorities fail using the "pip install trac" version
+    # on Travis CI. It is safe to allow the logic to continue after a failure
+    # here as they are really unimportant and can easily be configured later.
     for my $item (qw{component1 component2}) {
-        $TRAC_ADMIN->(
+        $TRAC_ADMIN_CONT->(
             "removing example component $item", q{component remove}, $item,
         );
     }
     for my $item (qw{1.0 2.0}) {
-        $TRAC_ADMIN->(
+        $TRAC_ADMIN_CONT->(
             "removing example version $item", q{version remove}, $item,
         );
     }
     for my $item (qw{milestone1 milestone2 milestone3 milestone4}) {
-        $TRAC_ADMIN->(
+        $TRAC_ADMIN_CONT->(
             "removing example milestone $item", q{milestone remove}, $item,
         );
     }
@@ -173,13 +182,16 @@ sub add_trac_environment {
         ['blocker'  => 'critical'],
     ) {
         my ($old, $new) = @{$item};
-        $TRAC_ADMIN->(
+        $TRAC_ADMIN_CONT->(
             "changing priority $old to $new", qw{priority change}, $old, $new,
         );
     }
     $TRAC_ADMIN->(
         "adding admin permission", qw{permission add admin TRAC_ADMIN},
     );
+    $TRAC_ADMIN->(
+        "adding admin permission", qw{permission add owner TRAC_ADMIN},
+    );
     my @admin_users = shellwords($CONFIG->get_trac_admin_users());
     for my $item (@admin_users) {
         $TRAC_ADMIN->(
@@ -275,11 +287,7 @@ sub backup_svn_repository {
     }
     my $base_name = $project->get_svn_base_name();
     run_mkpath($CONFIG->get_svn_backup_dir());
-    my $work_dir = tempdir(
-        "$base_name.backup.XXXXXX",
-        DIR => $CONFIG->get_svn_backup_dir(),
-        CLEANUP => 1,
-    );
+    my $work_dir = tempdir("$base_name.backup.XXXXXX", CLEANUP => 1, TMPDIR => 1);
     my $work_path = catfile($work_dir, $base_name);
     $RUN->(
         sprintf(
@@ -357,11 +365,7 @@ sub backup_trac_environment {
     my $trac_live_path = $project->get_trac_live_path();
     my $base_name = $project->get_name();
     run_mkpath($CONFIG->get_trac_backup_dir());
-    my $work_dir = tempdir(
-        "$base_name.backup.XXXXXX",
-        DIR => $CONFIG->get_trac_backup_dir(),
-        CLEANUP => 1,
-    );
+    my $work_dir = tempdir("$base_name.backup.XXXXXX", CLEANUP => 1, TMPDIR => 1);
     my $work_path = catfile($work_dir, $base_name);
     $RUNNER->run_with_retries(
         sprintf(
